==> drv_tapi-4.7.1.2.tar.gz: drv_tapi-4.7.1.2/src/drv_tapi_ppd.h <==
#ifndef _DRV_TAPI_PPD_H
#define _DRV_TAPI_PPD_H
/******************************************************************************

                              Copyright (c) 2009
                            Lantiq Deutschland GmbH
                     Am Campeon 3; 85579 Neubiberg, Germany

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

/**
   \file drv_tapi_ppd.h  
   This file contains the declaration of the Phone Plug Detection State 
   Machine.
*/

#if (TAPI_CFG_FEATURES & TAPI_FEAT_PHONE_DETECTION)
#include "ifx_types.h"

extern IFX_int32_t IFX_TAPI_PPD_Initialise_Unprot(TAPI_CHANNEL *pChannel);
extern IFX_void_t IFX_TAPI_PPD_Cleanup(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_HandleLineFeeding(TAPI_CHANNEL *pChannel,
                                           IFX_int32_t *pMode);
extern IFX_int32_t IFX_TAPI_PPD_ServiceStart(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_ServiceStop(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_HandleEvent(TAPI_CHANNEL *pChannel, 
                                     IFX_TAPI_EVENT_t *pEvent);
extern IFX_int32_t IFX_TAPI_PPD_Cfg_Get(TAPI_CHANNEL *pChannel, 
                                  IFX_TAPI_LINE_PHONE_DETECT_CFG_t *pPpdConf);
extern IFX_int32_t IFX_TAPI_PPD_Cfg_Set(TAPI_CHANNEL *pChannel, 
                             IFX_TAPI_LINE_PHONE_DETECT_CFG_t const *pPpdConf);
extern IFX_void_t IFX_TAPI_PPD_proc_read(TAPI_CHANNEL *pChannel, 
                                         IFX_uint32_t nDev,
                                         IFX_char_t *pBuf, 
                                         IFX_int32_t *pLen);
extern IFX_boolean_t IFX_TAPI_PPD_DisableEvent(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_CapMeasStop(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_CapMeasStart(TAPI_CHANNEL *pChannel);
#endif /* (TAPI_CFG_FEATURES & TAPI_FEAT_PHONE_DETECTION) */

#endif /* _DRV_TAPI_PPD_H */

==> drv_tapi-4.7.3.6.tar.gz: drv_tapi-4.7.3.6/src/drv_tapi_ppd.h <==
#ifndef _DRV_TAPI_PPD_H
#define _DRV_TAPI_PPD_H
/******************************************************************************

                              Copyright (c) 2009
                            Lantiq Deutschland GmbH
                     Am Campeon 3; 85579 Neubiberg, Germany

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

*******************************************************************************/

/**
   \file drv_tapi_ppd.h
   This file contains the declaration of the Phone Plug Detection State
   Machine.
*/

#if (TAPI_CFG_FEATURES & TAPI_FEAT_PHONE_DETECTION)
#include "ifx_types.h"

extern IFX_int32_t IFX_TAPI_PPD_Initialise_Unprot(TAPI_CHANNEL *pChannel);
extern IFX_void_t IFX_TAPI_PPD_Cleanup(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_HandleLineFeeding(TAPI_CHANNEL *pChannel,
                                           IFX_int32_t *pMode);
extern IFX_int32_t IFX_TAPI_PPD_ServiceStart(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_ServiceStop(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_HandleEvent(TAPI_CHANNEL *pChannel,
                                     IFX_TAPI_EVENT_t *pEvent);
extern IFX_int32_t IFX_TAPI_PPD_Cfg_Get(TAPI_CHANNEL *pChannel,
                                  IFX_TAPI_LINE_PHONE_DETECT_CFG_t *pPpdConf);
extern IFX_int32_t IFX_TAPI_PPD_Cfg_Set(TAPI_CHANNEL *pChannel,
                             IFX_TAPI_LINE_PHONE_DETECT_CFG_t const *pPpdConf);
extern IFX_void_t IFX_TAPI_PPD_proc_read(TAPI_CHANNEL *pChannel,
                                         IFX_uint32_t nDev,
                                         IFX_char_t *pBuf,
                                         IFX_int32_t *pLen);
extern IFX_boolean_t IFX_TAPI_PPD_DisableEvent(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_DisPhoneDetOnCh(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IFX_TAPI_PPD_EnPhoneDetOnCh(TAPI_CHANNEL *pChannel);
#endif /* (TAPI_CFG_FEATURES & TAPI_FEAT_PHONE_DETECTION) */

extern IFX_int32_t IOCTL_TAPI_PPD_CapMeasStop(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IOCTL_TAPI_PPD_NLTCapMeasStop(TAPI_CHANNEL *pChannel,
                                         IFX_TAPI_NLT_CAPACITANCE_STOP_t *pArg);
extern IFX_int32_t IOCTL_TAPI_PPD_CapMeasStart(TAPI_CHANNEL *pChannel);
extern IFX_int32_t IOCTL_TAPI_PPD_NLTCapMeasStart(TAPI_CHANNEL *pChannel,
                                        IFX_TAPI_NLT_CAPACITANCE_START_t *pArg);

#if (TAPI_CFG_FEATURES & TAPI_FEAT_PMC)
extern IFX_void_t IFX_TAPI_PMC_Exit(IFX_void_t);
extern IFX_int32_t IFX_TAPI_PMC_Init(IFX_void_t);
#endif /* (TAPI_CFG_FEATURES & TAPI_FEAT_PMC) */

#endif /* _DRV_TAPI_PPD_H */
